import os
import sys
import cairo
import memphis

RESOLUTION = 256
OUT = "tiles"

if len(sys.argv) > 1:
    zoom_level = int(sys.argv[1])
else:
    zoom_level = 14

if len(sys.argv) > 2:
    mapfile = sys.argv[2]
else:
    mapfile = "map.osm"

if not os.path.exists(OUT):
    os.mkdir(OUT, 0755)

memphis.debug_set_print_progress(True)

rules = memphis.RuleSet()
rules.load_from_file('rule.xml')

map = memphis.Map()
map.load_from_file('map.osm')
print map.get_bounding_box()

r = memphis.renderer_new_full(rules, map)
r.set_resolution(RESOLUTION)
print "Tile resolution: %d\n" % r.get_resolution()

maxx = r.get_max_x_tile(zoom_level)
maxy = r.get_max_y_tile(zoom_level)
i = r.get_min_x_tile(zoom_level)

for x in range(i, maxx+1):
    j = r.get_min_y_tile(zoom_level)
    for y in range(j, maxy+1):
        surface = cairo.ImageSurface(cairo.FORMAT_ARGB32, RESOLUTION, 
                RESOLUTION) 
        cr = cairo.Context(surface)
        path = 'tiles/%d_%d.png' % (x, y)
        
        print 'Drawing tile: %d, %d' % (x, y) 
        r.draw_tile(cr, x, y, zoom_level)
        surface.write_to_png(path)
